# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

#### Public Classes

* [`gitea`](#gitea): main class includes all other classes

#### Private Classes

* `gitea::config`: manages configuration files
* `gitea::install`: download and install gitea
* `gitea::service`: manage service state
* `gitea::service::user`: creates gitea service user

### Defined types

* [`gitea::custom::file`](#gitea--custom--file): gitea custom file

### Functions

* [`gitea::archive_resource`](#gitea--archive_resource): Returns source, checksum, and checksum_type params for downloading a gitea
release with the archive resource
* [`gitea::installed_version`](#gitea--installed_version): Returns the installed gitea version

## Classes

### <a name="gitea"></a>`gitea`

Install Gitea, a painless self-hosted Git service.
Review module hiera for default parameter values.

* **See also**
  * https://gitea.io

#### Examples

##### Basic usage

```puppet
include gitea
```

##### Install current supported release

```puppet
class { 'gitea':
  ensure => 'installed',
}
```

##### Install latest release and keep upgraded

```puppet
class { 'gitea':
  ensure => 'latest',
}
```

##### Install specific supported version

```puppet
class { 'gitea':
  ensure   => '1.18.0',
}
```

##### Install specific version not directly supported

```puppet
class { 'gitea':
  ensure   => '1.17.0',
  checksum => 'bc4a8e1f5d5f64d4be2e50c387de08d07c062aecdba2f742c2f61c20accfcc46',
}
```

##### Install compatible build from URL

```puppet
class { 'gitea':
  ensure   => 'https://codeberg.org/forgejo/forgejo/releases/download/v1.21.6-0/forgejo-1.21.6-0-linux-amd64',
  checksum => 'e86f446236a287b9ba2c65f8ff7b0a9ea4f451a5ffc3134f416f751e1eecf97c',
}
```

#### Parameters

The following parameters are available in the `gitea` class:

* [`manage_user`](#-gitea--manage_user)
* [`manage_group`](#-gitea--manage_group)
* [`manage_home`](#-gitea--manage_home)
* [`owner`](#-gitea--owner)
* [`group`](#-gitea--group)
* [`umask`](#-gitea--umask)
* [`home`](#-gitea--home)
* [`proxy`](#-gitea--proxy)
* [`base_url`](#-gitea--base_url)
* [`ensure`](#-gitea--ensure)
* [`checksum`](#-gitea--checksum)
* [`work_path`](#-gitea--work_path)
* [`default_configuration`](#-gitea--default_configuration)
* [`custom_configuration`](#-gitea--custom_configuration)
* [`manage_service`](#-gitea--manage_service)
* [`service_epp`](#-gitea--service_epp)
* [`tmpfile_epp`](#-gitea--tmpfile_epp)
* [`robots_txt`](#-gitea--robots_txt)
* [`run_path`](#-gitea--run_path)

##### <a name="-gitea--manage_user"></a>`manage_user`

Data type: `Boolean`

Should we manage provisioning the user?

##### <a name="-gitea--manage_group"></a>`manage_group`

Data type: `Boolean`

Should we manage provisioning the group?

##### <a name="-gitea--manage_home"></a>`manage_home`

Data type: `Boolean`

Should we manage provisioning the home directory?

##### <a name="-gitea--owner"></a>`owner`

Data type: `String`

The user owning gitea

##### <a name="-gitea--group"></a>`group`

Data type: `String`

The group owning gitea

##### <a name="-gitea--umask"></a>`umask`

Data type: `Pattern[/[0-7]{4}/]`

UMask of service process

##### <a name="-gitea--home"></a>`home`

Data type: `Optional[String]`

Qualified path to the user home directory

##### <a name="-gitea--proxy"></a>`proxy`

Data type: `Optional[String]`

Download gitea release via specified proxy

##### <a name="-gitea--base_url"></a>`base_url`

Data type: `String`

Download base URL

##### <a name="-gitea--ensure"></a>`ensure`

Data type: `Variant[Pattern[/\d+\.\d+\.\d+/],Enum['latest','installed'],Stdlib::HTTPUrl]`

Version of gitea to install, 'installed', 'latest', or URL a to release binary

##### <a name="-gitea--checksum"></a>`checksum`

Data type: `Optional[String]`

Checksum for the release binary

Default value: `undef`

##### <a name="-gitea--work_path"></a>`work_path`

Data type: `String`

Target directory for the gitea installation

##### <a name="-gitea--default_configuration"></a>`default_configuration`

Data type: `Hash`

Settings for configuring Gitea. A simple working configuration is
provided (see hiera). Generally this parameter should NOT be provided.
Instead set the custom_configuration parameter to override built-in
defaults.

##### <a name="-gitea--custom_configuration"></a>`custom_configuration`

Data type: `Hash`

Override default configuration for configuring Gitea.
The value is merged with the `default_configuration` parameter value.

##### <a name="-gitea--manage_service"></a>`manage_service`

Data type: `Boolean`

Should we manage a service definition for Gitea?

##### <a name="-gitea--service_epp"></a>`service_epp`

Data type: `String`

Path to service epp template file

##### <a name="-gitea--tmpfile_epp"></a>`tmpfile_epp`

Data type: `String`

Path to tmpfile epp template file

##### <a name="-gitea--robots_txt"></a>`robots_txt`

Data type: `String`

Allows to provide a http://www.robotstxt.org/ file to restrict crawling

##### <a name="-gitea--run_path"></a>`run_path`

Data type: `String`

Path to service runtime path

## Defined types

### <a name="gitea--custom--file"></a>`gitea::custom::file`

Manage files in the Gitea `CustomPath` folder

* **See also**
  * https://docs.gitea.io/en-us/customizing-gitea/

#### Examples

##### custom css

```puppet
gitea::custom::file { 'public/css/custom.css':
  content => file('profile/gitea/custom.css'),
}
```

##### custom logo

```puppet
gitea::custom::file { 'public/img/logo.svg':
  source => 'puppet:///modules/profile/gitea/logo.svg',
}
```

#### Parameters

The following parameters are available in the `gitea::custom::file` defined type:

* [`ensure`](#-gitea--custom--file--ensure)
* [`source`](#-gitea--custom--file--source)
* [`content`](#-gitea--custom--file--content)
* [`recurse`](#-gitea--custom--file--recurse)

##### <a name="-gitea--custom--file--ensure"></a>`ensure`

Data type: `Optional[Enum['file','absent']]`

Passed to File resource

Default value: `undef`

##### <a name="-gitea--custom--file--source"></a>`source`

Data type: `Variant[String,Undef]`

Passed to File resource

Default value: `undef`

##### <a name="-gitea--custom--file--content"></a>`content`

Data type: `Variant[String,Undef]`

Passed to File resource

Default value: `undef`

##### <a name="-gitea--custom--file--recurse"></a>`recurse`

Data type: `Variant[Boolean,Enum['remote']]`

Passed to File resource

Default value: `false`

## Functions

### <a name="gitea--archive_resource"></a>`gitea::archive_resource`

Type: Ruby 4.x API

Returns source, checksum, and checksum_type params for downloading a gitea
release with the archive resource

#### `gitea::archive_resource(String $gitea_bin, String $base_url, Hash $checksums, String $version, Optional[Variant[String,Undef]] $checksum_value)`

The gitea::archive_resource function.

Returns: `Hash`

##### `gitea_bin`

Data type: `String`



##### `base_url`

Data type: `String`



##### `checksums`

Data type: `Hash`



##### `version`

Data type: `String`



##### `checksum_value`

Data type: `Optional[Variant[String,Undef]]`



### <a name="gitea--installed_version"></a>`gitea::installed_version`

Type: Ruby 4.x API

Returns the installed gitea version

#### `gitea::installed_version(String $a)`

The gitea::installed_version function.

Returns: `Variant[String,Undef]`

##### `a`

Data type: `String`



